import useTransitioningState from './useTransitioningState.js';
/**
 * Hook to useState that supports asynchronous transitions
 *
 * State transitions may be queued via startTransition, and all queued transitions are completed in order by endTransition
 *
 * @typeParam S type of state
 * @param initialState
 * @param initialTransitioning if true, initializes the state with isTransitioning: true
 * @returns [state, startTransition, endTransition, isTransitioning]: SimpleTransitioningState<S>
 */
function useSimpleTransitioningState(initialState, initialTransitioning = false) {
    const [state, startTransition, endTransition, currentTransition] = useTransitioningState(initialState, initialTransitioning ? 'transitioning' : null);
    return [
        state,
        (action, isAsync = true) => startTransition(action, isAsync ? 'transitioning' : null),
        endTransition,
        currentTransition !== null,
    ];
}
export default useSimpleTransitioningState;
